/*
*
* Sample program for use with the Product
* Licensed Materials  - Property of IBM
* 5724-I66
* (c) Copyright IBM Corp.  2007
*   
*/
package com.ibm.wbit.tel.client.jsf.bean;

import java.util.HashMap;

import com.ibm.bpc.clientcore.DataObjectUtils;
import commonj.sdo.DataObject;

/**
 * BCCreateInstance represents a Business Case to be created on server.
 */
public class BCCreateInstance {
    
    /**
     * The value map which contains the values of the input message. 
     * Task input messages can be set by JSF pages. 
     */
	private HashMap inputValues = null;
	
	/**
     * The value map which contains the values of the custom properties. 
     * They can be set by JSF pages. 
     */
	private HashMap customPropertyValues = null;
	
	/**
	 * The qualified name of the input message, {NamespaceOfWSDLMessage}LocalNameOfWSDLMessage
	 */
	private String QNameInputMessage = null; 
	
	/**
	 * The type of Business Case to crate, this may be a Human Task or a Business Process.
	 */
	private int type = -1; 
	
	/**
	 * The type Business Process.
	 */
	public final static int TYPE_BUSINESS_PROCESS = 1; 
	
	/**
	 * The type Human Task.
	 */
	public final static int TYPE_HUMAN_TASK = 2; 
		 
    /**
     * The component name of the Business Case to create
     */
	private String componentName = null;
	
	 /**
     * The component name of the start activity to start Business Case 
     */
	private String componentNameStart = null;
	
	/**
     * The component namespace of the Business Case to create
     */
	private String componentNamespace = null;
	
	/**
	 * Constructor
	 */
	public BCCreateInstance() {
	    super();
	    inputValues = new HashMap();
	    customPropertyValues = new HashMap();
	}
	
	/**
	 * Clear all values of this instance
	 */
	public void clearAllValues(){
	    inputValues.clear();
	    customPropertyValues.clear();
	    type = -1; 
	    componentName = null; 
	    componentNameStart = null;
	    componentNamespace = null; 	 
	    QNameInputMessage = null;
	}
	 
    /**
     * Get the DataObject which contains the values for the input message.
     * 
     * @param dataObject the structure (may be empty) of the data object to get
     * @return the value map which contains the values for the input message
     */
    public DataObject getInputValues(DataObject dataObject) {
        return DataObjectUtils.putAll(dataObject, inputValues);
    }
    
    /**
     * Get the value map which contains the values of the input message. 
     * This can be get by JSF pages. 
     * 
     * @return the value map which contains the values of the input message
     */
    public HashMap getInputValues() {
        return inputValues;
    }
    
    /**
     * Set the value map which contains the values of the input message. 
     * This can be set by JSF pages.
     * 
     * @param inputValues value map which contains the values of the input message
     */
    public void setInputValues(HashMap inputValues) {
        this.inputValues = inputValues;
    } 
    
    /**
     * Get the value map which contains the values of the custom properties.  
     * They can be set by JSF pages. 
     * 
     * @return the value map which contains the values of the custom properties
     */
    public HashMap getCustomPropertyValues() {
        return customPropertyValues;
    }
    
    /**
     * Get qualified name of the input message, format: {NamespaceOfWSDLMessage}LocalNameOfWSDLMessage
     * 
     * @return qualified name of the input message
     */
    public String getQNameInputMessage() {
        return QNameInputMessage;
    }
    
    /**
     * Set qualified name of the input message, format: {NamespaceOfWSDLMessage}LocalNameOfWSDLMessage
     * 
     * @param nameInputMessage qualified name of the input message
     */
    public void setQNameInputMessage(String nameInputMessage) {
        QNameInputMessage = nameInputMessage;
    }
    
    /**
     * Get the component name of this Business Case
     * 
     * @return component name of this Business Case
     */
    public String getComponentName() {
        return componentName;
    }
    
    /**
     * Set the component name of this Business Case
     * 
     * @param component name of this Business Case
     */
    public void setComponentName(String componentName) {
        this.componentName = componentName;
    }
    
    /**
     * Get the component name used to start this Business Case
     * 
     * @return component name of this Business Case
     */
    public String getComponentNameStart() {
        return componentNameStart;
    }
    
    /**
     * Set the component name used to start this Business Case
     * 
     * @param component name used to start this Business Case
     */
    public void setComponentNameStart(String componentNameStart) {
        this.componentNameStart = componentNameStart;
    }
    
    /**
     * Get the component namespace of this Business Case
     * 
     * @return component namespace of this Business Case
     */
    public String getComponentNamespace() {
        return componentNamespace;
    }
    
    /**
     * Set the component namespace of this Business Case
     * 
     * @param component namespace of this Business Case
     */
    public void setComponentNamespace(String componentNamespace) {
        this.componentNamespace = componentNamespace;
    }
    
    /**
     * Get the type of this Business Case
     * 
     * @return type of this Business Case
     */
    public int getType() {
        return type;
    }
    
    /**
     * Set the type of this Business Case
     * 
     * @param type of this Business Case
     */
    public void setType(int type) {
        this.type = type;
    }
      
}
