/*
*
* Sample program for use with the Product
* Licensed Materials  - Property of IBM
* 5724-I66
* (c) Copyright IBM Corp.  2007
*   
*/
package com.ibm.wbit.tel.client.jsf.bean;

import java.util.HashMap;

import com.ibm.bpc.clientcore.DataObjectUtils;
import com.ibm.task.api.QueryResultSet;
import com.ibm.task.clientmodel.HTMConnection;
import com.ibm.task.clientmodel.bean.TaskInstanceBean;
import commonj.sdo.DataObject;

/**
 * ToDoInstance represents an entry in list open ToDos and under work ToDos. 
 */
public class ToDoInstance extends TaskInstanceBean {

	/**
     * The value map which contains the values of the input message. 
     * Task input messages can be get by JSF pages. 
     */
	private HashMap inputValues = null;
	
	/**
     * The value map which contains the values for the output message.
     * Task output messages can be set by JSF pages. 
     */
	private HashMap outputValues = null;
    
    
    /**
	 * Constructs a ToDoInstance from a query result set returned by the HumanTaskManager API
	 * 
	 * @param resultSet the query result from a query call; represents a row of this result
	 * @param htmConnection the connection to the Human Task Manager
	 */
    public ToDoInstance(QueryResultSet resultSet, HTMConnection htmConnection) {
        super(resultSet, htmConnection);
            
    }

	/**
     * Get the value map which contains the values of the input message. 
     * This can be get by JSF pages. 
     * 
     * @return the value map which contains the values of the input message
     */
    public HashMap getInputValues() {
        return inputValues;
    }
    
    /**
     * Set the value map which contains the values of the input message. 
     * This can be set by JSF pages.
     * 
     * @param inputValues value map which contains the values of the input message
     */
    public void setInputValues(HashMap inputValues) {
        this.inputValues = inputValues;
    }
    
    /**
     * Set the DataObject which contains the values of the input message. 
     * DataObject from Task input message. 
     * 
     * @param inputValues DataObject which contains the values of the input message
     */
    public void setInputValues(DataObject inputValues) {
        this.inputValues = (HashMap) DataObjectUtils.getValueMap(inputValues);
    }
    
    /**
     * Get the value map which contains the values for the output message.
     * This can be get by JSF pages.
     * 
     * @return the value map which contains the values for the output message
     */
    public HashMap getOutputValues() {
        return outputValues;
    }
    
    /**
     * Get the DataObject which contains the values for the output message.
     * DataObject for Task output message.
     * 
     * @param dataObject the structure (may be empty) of the data object to get
     * @return the value map which contains the values for the output message
     */
    public DataObject getOutputValues(DataObject dataObject) {
        return DataObjectUtils.putAll(dataObject, outputValues);
    }
    
    /**
     * Set the value map which contains the values for the output message.
     * This can be set by JSF pages. 
     * 
     * @param outputValues the value map which contains the values for the output message
     */
    public void setOutputValues(HashMap outputValues) {
        this.outputValues = outputValues;
    }   
    
    /**
     * Set the DataObject which contains the values of the output message. 
     * DataObject from Task output message. 
     * 
     * @param outputValues DataObject which contains the values of the output message
     */
    public void setOutputValues(DataObject outputValues) {
        this.outputValues = (HashMap) DataObjectUtils.getValueMap(outputValues);
    }

}
