/*
*
* Sample program for use with the Product
* Licensed Materials  - Property of IBM
* 5724-I66
* (c) Copyright IBM Corp.  2007
*   
*/
package com.ibm.wbit.tel.client.jsf.handler;

import java.util.ArrayList;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;

import javax.faces.event.ActionEvent;

import com.ibm.bpe.jsf.handler.ItemProvider;
import com.ibm.wbit.tel.client.jsf.bean.BCCreateInstance;
import com.ibm.wbit.tel.client.jsf.infrastructure.FacesUtils;
import com.ibm.wbit.tel.client.jsf.infrastructure.Messages;
import com.ibm.wbit.tel.client.jsf.infrastructure.SharedConstants;


/** 
 * BCCreateMessageHandler acts as listener for command links.
 * It extends  SubviewHandler to bring up a page which shows the 
 * input message and and custom properties for the selected action.   
 * Furthermore it is an ItemProvider and can therefore be used as a model 
 * in the command bar component. 
 */
public class BCCreateMessageHandler extends SubviewHandler implements ItemProvider, SharedConstants {

    /**
	 * Hashmap to get the namespace of a component, for which the client has been generated for. 
	 * key: component name, value: component namespace
	 */	
    private HashMap componentNamespaces;
    
	    
    /**
     * The Business Case that shoud be created on server.
     */
    private BCCreateInstance bcCreateInstance;
       
    /**
     * Action event of a command link.
     * Provide the next subviewIDs and decorate an instance of BCCreateInstance 
     * to create a new business case on server. 
     * 
     * @param actionEvent of command link
     */
    public void itemSelected(ActionEvent actionEvent) {

        String action = (String) actionEvent.getComponent().getAttributes().get("value");
        int sepIdxFirst = action.indexOf(NAVIGATION_SEPARATOR);
        int sepIdxSecond = action.indexOf(NAVIGATION_SEPARATOR, sepIdxFirst + 1);
        String componentName = action.substring(0, sepIdxFirst);
        String QNameInputMessage, componentNameStart;

        if (sepIdxSecond == -1) {
            QNameInputMessage = action.substring(sepIdxFirst + 1, action.length());
            componentNameStart = null;
        } else {
            QNameInputMessage = action.substring(sepIdxFirst + 1, sepIdxSecond);
            componentNameStart = action.substring(sepIdxSecond + 1, action.length());
        }

        nextSubviewCustomProperties(componentName);
        nextSubviewInput(QNameInputMessage);

        if (bcCreateInstance == null) {
            bcCreateInstance = new BCCreateInstance();
        }
        bcCreateInstance.clearAllValues();
        bcCreateInstance.setComponentName(componentName);
        bcCreateInstance.setComponentNameStart(componentNameStart);
        bcCreateInstance.setComponentNamespace((String) componentNamespaces.get(componentName));
        bcCreateInstance.setQNameInputMessage(QNameInputMessage);
        
        String preNavigation = Messages.getString("LINE_BCCREATE", FacesUtils.getLocale())+" > ";
        if (componentNameStart == null) {
            bcCreateInstance.setType(BCCreateInstance.TYPE_HUMAN_TASK);
            setNavigationInfo(preNavigation + componentName);
        } else {
            bcCreateInstance.setType(BCCreateInstance.TYPE_BUSINESS_PROCESS);
            setNavigationInfo(preNavigation + componentName + " > "+ componentNameStart);
        }

    }
    
    
    /**
     * Provide the BCCreateInstance selected in the list, e.g. to the command bar component.
     * 
     * @see com.ibm.bpe.jsf.handler.ItemProvider#getSelectedItems()
     */
	public List getSelectedItems() {
		
		List list = Collections.EMPTY_LIST; 
		if(bcCreateInstance != null)
		{
			list = new ArrayList(1);
			list.add(bcCreateInstance);
		}
		return list;
	}
	
	
	/**
	 * Get the BCCreateInstance selected in list.
	 * 
	 * @return
	 */
    public BCCreateInstance getBcCreateInstance() {
        return bcCreateInstance;
    }
    
    
	/**
	 * Set Hashmap to get the namespace of a component, for which the client has been generated for. 
	 * key: component name, value: component namespace
	 * 
	 * @param componentNamespaces Hashmap to get the namespace of a component
	 */	
    public void setComponentNamespaces(HashMap componentNamespaces) {
        this.componentNamespaces = componentNamespaces;
    }
    
   
    
	/**
	 * Hashmap to get the namespace of a component, for which the client has been generated for. 
	 * key: component name, value: component namespace
	 * 
	 * @return Hashmap to get the namespace of a component
	 */	
    public HashMap getComponentNamespaces() {
        return componentNamespaces;
    }
       
}
