/*
*
* Sample program for use with the Product
* Licensed Materials  - Property of IBM
* 5724-I66
* (c) Copyright IBM Corp.  2007
*   
*/
package com.ibm.wbit.tel.client.jsf.handler;


import java.util.HashMap;


/**
 * SubviewHandler can be used to set/get the subview ID of the subview that should be shown next,
 * according to a passed key. In case of determing a message subview the passed key must be the 
 * QName of that message. In case of determing a subview for custom properties subview the passed
 * key must be the component name for wich to show the custom properties.  
 */
public class SubviewHandler {
    
    /**
     * ID of next subview for custom properties
     */
    private String subviewIDCustomProperties;
    
    /**
     * ID of next subview for input message
     */
    private String subviewIDInput;
    
    /**
     * ID of next subview for output message 
     */
    private String subviewIDOutput;
    
    /**
     * Map of available sub views. 
     */
    private HashMap subviewMap;

    /**
     * To get navigation info to be shown in the JSF pages.
     */
    private String navigationInfo; 
        
    /**
     * Provide the next subview for input message according to passed key.
     * 
     * @param key
     */
    public void nextSubviewInput(String key) {
        Object obj =  subviewMap.get(key);
        
        if (obj != null) {
            this.subviewIDInput = (String) obj;
        } else {
            this.subviewIDInput = null;
        }
    }

    /**
     * Provide the next subview for output message according to passed key.
     * 
     * @param key
     */
    public void nextSubviewOutput(String key) {
        Object obj =  subviewMap.get(key);
        
        if (obj != null) {
            this.subviewIDOutput = (String) obj;
        } else {
            this.subviewIDOutput = null;
        }
    }
    
    /**
     * Provide the next subview for custom properties according to passed key.
     * 
     * @param key
     */
    public void nextSubviewCustomProperties(String key) {
        Object obj =  subviewMap.get(key);
        
        if (obj != null) {
            this.subviewIDCustomProperties = (String) obj;
        } else {
            this.subviewIDCustomProperties = null;
        }
      }
    
    /**
     * Get ID of next subview
     * 
     * @return ID of next subview
     */
    public String getSubviewIDCustomProperties() {
        return subviewIDCustomProperties;
    }
                
    /**
     * Get ID of next subview for input message
     * 
     * @return ID of next subview for input message
     */
    public String getSubviewIDInput() {
        return subviewIDInput;
    }
            
    /**
     * Get ID of next subview for output message
     * 
     * @return ID of next subview for output message
     */
    public String getSubviewIDOutput() {
        return subviewIDOutput;
    }
         
    /**
     * Get the subViewMap
     * 
     * @return
     */
    public HashMap getSubviewMap() {
        return subviewMap;
    }
    
    /**
     * Set subviewMap.
     * 
     * @param subviewMap
     */
    public void setSubviewMap(HashMap subviewMap) {
        this.subviewMap = subviewMap;
    }
    
    /**
     * Set subviewIDCustomProperties.
     * 
     * @param subviewIDCustomProperties
     */
    public void setSubviewIDCustomProperties(String subviewIDCustomProperties) {
        this.subviewIDCustomProperties = subviewIDCustomProperties;
    }
    
    
    /**
     * Get navigation info to be shown in the JSF pages.
     * 
     * @return navigation info to be shown in the JSF pages.
     */
    public String getNavigationInfo() {
        return navigationInfo;
    }
    
    
   /**
    * Set navigation info to be shown in the JSF pages.
    * 
    * @param navigation info to be shown in the JSF pages.
    */
    public void setNavigationInfo(String navigationInfo) {
        this.navigationInfo = navigationInfo;
    }
    
}
