/*
 *
 * Sample program for use with the Product
 * Licensed Materials  - Property of IBM
 * 5724-I66
 * (c) Copyright IBM Corp.  2007 *   
 */
package com.ibm.wbit.tel.client.jsf.infrastructure;

import java.util.Locale;

import javax.faces.context.ExternalContext;
import javax.faces.context.FacesContext;
import javax.faces.el.ValueBinding;

/**
 * This class provides some general utilities, usefully in the context of JSF.
 */
public class FacesUtils {

    
    /**
     * Get the external context of faces application.
     * 
     * @return external context of faces application
     */
    public static ExternalContext getContext() {
        FacesContext facesContext = FacesContext.getCurrentInstance();

        return (facesContext == null) ? null : facesContext.getExternalContext();
    }

    
    /**
     * Return the locale of the request.
     * 
     * @return the locale
     */
    public static Locale getLocale() {
        Locale locale = null;

        if (getContext() != null) {
            locale = getContext().getRequestLocale();
        }

        if (locale == null) {
            locale = new Locale("en", "us");
        }

        return locale;
    }

    
    /**
     * Get managed bean instance for passed name. 
     * The passed name must be defined in faces-config as <managed-bean-name>
     * 
     * @param managedBeanName
     *            as of <managed-bean-name></managed-bean-name> in faces-config.
     * @return managed bean instance for passed name
     */
    public static Object getManagedBeanInstance(String managedBeanName) {

        String name = "#{" + managedBeanName + "}";

        ValueBinding vb = FacesContext.getCurrentInstance().getApplication().createValueBinding(name);

        return vb.getValue(FacesContext.getCurrentInstance());
    }

}
